@@ -74,6 +74,19 @@ See also the `profile' slot in the `browser' class.")
               :color ,theme:on-background
               :margin-left "20px"
               :margin-top "20px")
+            `(ul
+              :margin-top "0"
+              :margin-bottom "0")
+            `("details > *"
+              :margin-left "18px")
+            `("details > ul"
+              :margin-left "inherit")
+            `("details summary"
+              :margin-left "inherit"
+              :margin-bottom "8px"
+              :cursor "pointer")
+            `("summary::-webkit-details-marker"
+              :padding-bottom "4px")
             `(.section
               :margin-top "2em")
             `("h1"
@@ -172,13 +185,18 @@ See also the `profile' slot in the `browser' class.")
               :background-color ,theme:background
               :border "2px" solid ,theme:primary
               :padding "5px")
+            `("table"
+              :border-radius "3px"
+              :border-spacing "0"
+              :width "100%")
             `("table, th, td"
               :border-color ,theme:secondary
-              :border-collapse "collapse"
               :border-width "1px"
               :border-style "solid"
               :background-color ,theme:background
               :color ,theme:on-background)
+            `("td, th"
+              :padding "6px")
             `(th
               :background-color ,theme:primary
               :color ,theme:on-primary
@@ -809,14 +827,10 @@ Also see `panel-page'."))
    (display-tabs-by-last-access-p
     nil
     :documentation "Whether tabs are dynamically ordered by last access time.")
-   (glyph-left #.(alexandria:read-file-into-string
-                  (asdf:system-relative-pathname :nyxt "assets/left.svg")))
-   (glyph-right #.(alexandria:read-file-into-string
-                   (asdf:system-relative-pathname :nyxt "assets/right.svg")))
-   (glyph-reload #.(alexandria:read-file-into-string
-                    (asdf:system-relative-pathname :nyxt "assets/reload.svg")))
-   (glyph-lambda #.(alexandria:read-file-into-string
-                    (asdf:system-relative-pathname :nyxt "assets/lambda.svg")))
+   (glyph-left (gethash "left.svg" *static-data*))
+   (glyph-right (gethash "right.svg" *static-data*))
+   (glyph-reload (gethash "reload.svg" *static-data*))
+   (glyph-lambda (gethash "lambda.svg" *static-data*))
    (style (theme:themed-css (theme *browser*)
             `(body
               :line-height "24px"
@@ -838,10 +852,10 @@ Also see `panel-page'."))
               ("0%" :transform "rotate(0deg)")
               ("100%" :transform "rotate(360deg)"))
             `(".arrow-right"
-              :clip-path "polygon(0 0, calc(100% - 10px) 0, 100% 50%, calc(100% - 10px) 100%, 0 100%)"
+              :clip-path "polygon(0 0, calc(100% - 10px) 0, 100% calc(50% - 1px), 100% 50%, 100% calc(50% + 1px), calc(100% - 10px) 100%, 0 100%)"
               :margin-right "-10px")
             `(".arrow-left"
-              :clip-path "polygon(10px 0, 100% 0, 100% 100%, 10px 100%, 0% 50%)"
+              :clip-path "polygon(10px 0, 100% 0, 100% 100%, 10px 100%, 0px calc(50% + 1px), 0% 50%, 0px calc(50% - 1px))"
               :margin-left "-10px")
             `("#container"
               :display "flex"
@@ -910,7 +924,7 @@ Also see `panel-page'."))
               :border-radius "1px"
               :font "inherit"
               :outline "inherit"
-              :clip-path "polygon(calc(100% - 10px) 0, 100% 50%, calc(100% - 10px) 100%, 0% 100%, 10px 50%, 0% 0%)")
+              :clip-path "polygon(calc(100% - 10px) 0, 100% calc(50% - 1px), 100% 50%, 100% calc(50% + 1px), calc(100% - 10px) 100%, 0% 100%, 10px calc(50% + 1px), 10px 50%, 10px calc(50% - 1px),  0% 0%)")
             `(".tab:hover"
               :opacity 0.8
               :cursor "pointer")
