@@ -824,3 +824,24 @@ Chromium, Brave and Vivaldi. For instance, "
      (:li "Add Public Sans font and set it as the default.")
      (:li "Redesign status buffer buttons.")
      (:li "Minor review of " (:a :href (nyxt-url 'new) "start page") "."))))
+
+(define-version "3.6.1"
+  (:nsection :title "Bug fixes"
+    (:ul
+     (:li "Fix clipboard facilities on X11 and Wayland.")
+     (:li "Fix source code location on Flatpak.")
+     (:li "Fix " (:nxref :mode 'nyxt/mode/style:dark-mode)
+        " and the " (:nxref :command 'nyxt/mode/bookmarklets:darken)
+        " bookmarklet command."))))
+
+(define-version "3.7.0"
+  (:nsection :title "UI/UX"
+    (:ul
+     (:li "Minor UI improvements on the status and prompt buffer.")
+     (:li "Stylistic review of the manual to improve readability.")))
+  (:nsection :title "Features"
+    (:ul
+     (:li "Add possibility to open PDF files via command "
+          (:nxref :command 'nyxt/mode/file-manager:open-file) ".")
+     (:li "The installation process now takes into account the Appdata file and
+a scalable icon."))))
